'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var core = require('@tiptap-es5/core');

var inputRegex = /(?:^|\s)((?:==)((?:[^~]+))(?:==))$/gm;
var pasteRegex = /(?:^|\s)((?:==)((?:[^~]+))(?:==))/gm;
var Highlight = core.Mark.create({
    name: 'highlight',
    defaultOptions: {
        multicolor: false,
        HTMLAttributes: {},
    },
    addAttributes: function () {
        if (!this.options.multicolor) {
            return {};
        }
        return {
            color: {
                default: null,
                parseHTML: function (element) {
                    return {
                        color: element.getAttribute('data-color') || element.style.backgroundColor,
                    };
                },
                renderHTML: function (attributes) {
                    if (!attributes.color) {
                        return {};
                    }
                    return {
                        'data-color': attributes.color,
                        style: "background-color: " + attributes.color,
                    };
                },
            },
        };
    },
    parseHTML: function () {
        return [
            {
                tag: 'mark',
            },
        ];
    },
    renderHTML: function (_a) {
        var HTMLAttributes = _a.HTMLAttributes;
        return ['mark', core.mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
    },
    addCommands: function () {
        return {
            setHighlight: function (attributes) { return function (_a) {
                var commands = _a.commands;
                return commands.setMark('highlight', attributes);
            }; },
            toggleHighlight: function (attributes) { return function (_a) {
                var commands = _a.commands;
                return commands.toggleMark('highlight', attributes);
            }; },
            unsetHighlight: function () { return function (_a) {
                var commands = _a.commands;
                return commands.unsetMark('highlight');
            }; },
        };
    },
    addKeyboardShortcuts: function () {
        var _this = this;
        return {
            'Mod-Shift-h': function () { return _this.editor.commands.toggleHighlight(); },
        };
    },
    addInputRules: function () {
        return [
            core.markInputRule(inputRegex, this.type),
        ];
    },
    addPasteRules: function () {
        return [
            core.markPasteRule(inputRegex, this.type),
        ];
    },
});

exports.Highlight = Highlight;
exports.default = Highlight;
exports.inputRegex = inputRegex;
exports.pasteRegex = pasteRegex;
//# sourceMappingURL=tiptap-extension-highlight.cjs.js.map
