import { Mark, mergeAttributes, markInputRule, markPasteRule } from '@tiptap-es5/core';

var inputRegex = /(?:^|\s)((?:==)((?:[^~]+))(?:==))$/gm;
var pasteRegex = /(?:^|\s)((?:==)((?:[^~]+))(?:==))/gm;
var Highlight = Mark.create({
    name: 'highlight',
    defaultOptions: {
        multicolor: false,
        HTMLAttributes: {},
    },
    addAttributes: function () {
        if (!this.options.multicolor) {
            return {};
        }
        return {
            color: {
                default: null,
                parseHTML: function (element) {
                    return {
                        color: element.getAttribute('data-color') || element.style.backgroundColor,
                    };
                },
                renderHTML: function (attributes) {
                    if (!attributes.color) {
                        return {};
                    }
                    return {
                        'data-color': attributes.color,
                        style: "background-color: " + attributes.color,
                    };
                },
            },
        };
    },
    parseHTML: function () {
        return [
            {
                tag: 'mark',
            },
        ];
    },
    renderHTML: function (_a) {
        var HTMLAttributes = _a.HTMLAttributes;
        return ['mark', mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
    },
    addCommands: function () {
        return {
            setHighlight: function (attributes) { return function (_a) {
                var commands = _a.commands;
                return commands.setMark('highlight', attributes);
            }; },
            toggleHighlight: function (attributes) { return function (_a) {
                var commands = _a.commands;
                return commands.toggleMark('highlight', attributes);
            }; },
            unsetHighlight: function () { return function (_a) {
                var commands = _a.commands;
                return commands.unsetMark('highlight');
            }; },
        };
    },
    addKeyboardShortcuts: function () {
        var _this = this;
        return {
            'Mod-Shift-h': function () { return _this.editor.commands.toggleHighlight(); },
        };
    },
    addInputRules: function () {
        return [
            markInputRule(inputRegex, this.type),
        ];
    },
    addPasteRules: function () {
        return [
            markPasteRule(inputRegex, this.type),
        ];
    },
});

export default Highlight;
export { Highlight, inputRegex, pasteRegex };
//# sourceMappingURL=tiptap-extension-highlight.esm.js.map
